export declare type Day = "Monday" | "Tuesday" | "Wednesday" | "Thursday" | "Friday" | "Saturday" | "Sunday";
export declare type InputSlot = ({
    /**
     * Day of the week (e.g. Monday).
     */
    day: Day;
    /**
     * Time in 24 hour format (e.g. 14:30).
     */
    from: string;
    /**
     * Time in 24 hour format (e.g. 17:45).
     */
    to: string;
    /**
     * IANA zone (e.g. "America/New_York"). Defaults to local.
     */
    timezone?: string;
} | {
    /**
     * ISO string.
     */
    from: string;
    /**
     * ISO string.
     */
    to: string;
}) & {
    /**
     * Any other metadata.
     */
    metadata?: Record<any, any>;
};
export interface OutputSlot {
    /**
     * ISO string.
     */
    from: string;
    /**
     * ISO string.
     */
    to: string;
    /**
     * Is this slot available?
     */
    available: boolean;
    /**
     * Array of metadata which is available for this slot.
     */
    metadataAvailable?: Record<any, any>[];
    /**
     * Array of metadata which is unavailable for this slot.
     */
    metadataUnavailable?: Record<any, any>[];
}
export interface GetSlots {
    /**
     * An array of all generated slots. Only use this as a starting point for manipulating the output.
     */
    allSlots: OutputSlot[];
    /**
     * An array of available slots. Only use this as a starting point for manipulating the output.
     */
    availableSlots: OutputSlot[];
    /**
     * An array of dates, including unavailable ones, between the from and to configuration variables. Use this to allow users to specify their own datetime, but within your chosen bounds.
     */
    allDates: string[];
    /**
     * An array of available dates. Use this to mark on a calendar which dates can be selected.
     */
    availableDates: string[];
    /**
     * Once a user has selected a date, use this object to easily find all the slots for that day.
     */
    allSlotsByDay: Record<string, OutputSlot[]>;
    /**
     * Once a user has selected a date, use this object to easily find the available slots for that day.
     */
    availableSlotsByDay: Record<string, OutputSlot[]>;
    /**
     * Worried that the number crunching is slowing down your app? Monitor this variable to see the time taken by slot calculator.
     */
    timeTaken: string;
}
export declare function getSlots(config: {
    /**
     * ISO string. Input slots outside of this will be ignored.
     */
    from?: string;
    /**
     * ISO string. Input slots outside of this will be ignored.
     */
    to?: string;
    /**
     * List of available input slots.
     */
    availability?: InputSlot[];
    /**
     * List of unavailable input slots.
     */
    unavailability?: InputSlot[];
    /**
     * Duration of each output slot in minutes.
     */
    duration: number;
    /**
     * IANA zone (e.g. "Europe/Paris"). Defaults to local.
     */
    outputTimezone?: string;
    /**
     * If `true`, all times within bounds are available by default. Defaults to `true` if `availability` is not set. Defaults to `false` otherwise.
     */
    defaultAvailable?: boolean;
}): {
    allSlots: OutputSlot[];
    availableSlots: OutputSlot[];
    allDates: string[];
    availableDates: string[];
    allSlotsByDay: Record<string, OutputSlot[]>;
    availableSlotsByDay: Record<string, OutputSlot[]>;
    timeTaken: string;
};
declare const _default: {
    getSlots: typeof getSlots;
};
export default _default;
